@@ -13,8 +13,8 @@ function (Ra, Rb, scale = 12)
     assetReturns.vec = checkDataVector(Ra)
     benchmarkReturns.vec = checkDataVector(Rb)
 
-    TrackingError = sqrt(sum(assetReturns.vec - benchmarkReturns.vec)^2 / (length(assetReturns.vec) - 1)) * sqrt(scale)
-
+    #TrackingError = sqrt(sum(assetReturns.vec - benchmarkReturns.vec)^2 / (length(assetReturns.vec) - 1)) * sqrt(scale)
+    TrackingError = sd(assetReturns.vec - benchmarkReturns.vec) * sqrt(scale)
     TrackingError
 
 }
@@ -22,15 +22,21 @@ function (Ra, Rb, scale = 12)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: TrackingError.R,v 1.5 2007/04/04 00:23:01 brian Exp $
+# $Id: TrackingError.R,v 1.8 2008-06-30 21:42:09 peter Exp $
 #
 ###############################################################################
 # $Log: TrackingError.R,v $
+# Revision 1.8  2008-06-30 21:42:09  peter
+# - fixed bad encoding
+#
+# Revision 1.6  2008-06-02 16:05:19  brian
+# - update copyright to 2004-2008
+#
 # Revision 1.5  2007/04/04 00:23:01  brian
 # - typos and minor comment updates
 #
