@@ -1,5 +1,5 @@
 `UpsidePotentialRatio` <-
-function (Ra, MAR = 0)
+function (Ra, MAR = 0, method=c("subset","full"))
 { # @author Brian G. Peterson
 
     # Description:
@@ -9,18 +9,30 @@ function (Ra, MAR = 0)
 
     # Ra    return vector
     # MAR   minimum acceptable return
+
+    method = method[1] # grab the first value if this is still a vector, to avoid varnings
+
     # Function:
 
     Ra = checkData(Ra, method = "vector")
 
+    if(!is.null(dim(MAR)))
+        MAR = mean(checkData(MAR, method = "vector"))
+
     r = subset(Ra,Ra > MAR)
-    return( ( sum(r - MAR)/(length(Ra)) )/ DownsideDeviation(Ra, MAR) )
+
+    switch(method,
+        full   = {len = length(Ra)},
+        subset = {len = length(r)} #previously length(R)
+    ) # end switch
+
+    return( ( sum(r - MAR)/len )/ DownsideDeviation(Ra, MAR=MAR , method=method) )
 }
 
 `UPR`<-
-function (Ra, MAR = 0)
+function (Ra, MAR = 0, method=c("subset","full"))
 { # @author Brian G. Peterson
-    UpsidePotentialRatio(Ra=Ra, MAR=MAR)
+    UpsidePotentialRatio(Ra=Ra, MAR=MAR, method=method)
 }
 
 ###############################################################################
@@ -31,10 +43,15 @@ function (Ra, MAR = 0)
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: UpsidePotentialRatio.R,v 1.2 2008-06-02 16:05:19 brian Exp $
+# $Id: UpsidePotentialRatio.R,v 1.3 2008-09-30 21:17:24 brian Exp $
 #
 ###############################################################################
 # $Log: UpsidePotentialRatio.R,v $
+# Revision 1.3  2008-09-30 21:17:24  brian
+# - both DownsideDeviation and UpsidePotentialRatio now support "method argument to use full or subset of series
+# - use subset as default method
+# - updated documentation to reflect change
+#
 # Revision 1.2  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
