@@ -1,12 +1,9 @@
 `chart.Regression` <-
-function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xlim = NA, colorset = 1:12, symbolset = 1:12, darken = FALSE , legend.loc = NULL, ylog = FALSE, fit = c("loess", "linear", "spline"), span = 2/3, degree = 1, family = c("symmetric", "gaussian"),  ylim = NA, evaluation = 50, cex= .8, ...)
+function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Title", ylab=NULL, xlab=NULL, xlim = NA, colorset = 1:12, symbolset = 1:12, darken = FALSE , legend.loc = NULL, ylog = FALSE, fit = c("loess", "linear", "conditional", "quadratic"), span = 2/3, degree = 1, family = c("symmetric", "gaussian"),  ylim = NA, evaluation = 50, legend.cex= 0.8, cex = 0.8, lwd = 2, ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
-    # Draws a scatter chart.  This is another chart "primitive", since it
-    # only contains a set of sensible defaults.  This function is
-    # intended to be used in a wrapper that is written for a particular purpose.
-    # This is just a handy way to standardize the formatting of multiple charts.
+    # Draws a scatter chart.  
 
     # Inputs:
     # x and y = assumes that data is a regular time series, not irregular.  Can take
@@ -25,6 +22,23 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
     # Output:
     # Draws a scatter chart with some sensible defaults.
 
+# @todo: Add a quadratic curve fit
+    # Because there appears to be a bit of a bend in the scatterplot, let's try fitting a quadratic curve instead of a linear curve. Note: Fitting a quadratic curve is still considered linear regression. This may seem strange, but the reason is that the quadratic regression model assumes that the response y is a linear combination of 1, x, and x2. Notice the special form of the lm command when we implement quadratic regression. The I function means "as is" and it resolves any ambiguity in the model formula:
+    # 
+    #    model2 <- lm(y~x+I(x^2))
+    #    summary(model2)
+    # 
+    # Here is how to find the estimates of beta using the closed-form solution:
+    # 
+    #    X <- cbind(1, x, x^2) # Create nx3 X matrix
+    #    solve(t(X) %*% X) %*% t(X) %*% y # Compare to the coefficients above
+    # 
+    # Plotting the quadratic curve is not a simple matter of using the abline function. To obtain the plot, we'll first create a sequence of x values, then apply the linear combination implied by the regression model using matrix multiplication:
+    # 
+    #    xx <- seq(min(x),max(x),len=200)
+    #    yy <- model2$coef %*% rbind(1,xx,xx^2)
+    #    lines(xx,yy,lwd=2,col=3)
+
     # FUNCTION:
 
 
@@ -48,6 +62,8 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
 
     if(is.na(xlim[1]))
         xlim = range(as.vector(na.omit(Rb)))
+    xmin = xlim[1]
+    xmax = xlim[2]
     if(is.na(ylim[1]))
         ylim = range(as.vector(na.omit(Ra))) #range(Ra, r.loess$y, na.rm = TRUE)
     if(is.null(xlab)){
@@ -87,14 +103,14 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
            for (s_fit in fit) {
               switch(s_fit,
                     linear = {
-                        abline(lm( merged.assets.df[,1] ~ merged.assets.df[,2]), col = colorset[color.tic])
+                        abline(lm( merged.assets.df[,1] ~ merged.assets.df[,2]), col = colorset[color.tic], lwd = lwd)
                     },
                     loess = { # see scatter.smooth
                         #r.loess = 0
                         r.loess = loess.smooth(merged.assets.df[,2], merged.assets.df[,1], span, degree, family, evaluation)
                         lines(r.loess, col = colorset[color.tic], lty = 2)
                         #lines(loess(merged.assets.df[,2] ~ merged.assets.df[,1]), col = colorset[color.tic])
-                    }#,
+                    },
                     # commented because it is similar to loess in default parameters
                     # spline = {
                     #    # requires library(pspline)
@@ -102,6 +118,18 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
                     #    lines(r.spline, col = colorset[color.tic], lty = 4)
                     #    #lines(loess(merged.assets.df[,2] ~ merged.assets.df[,1]), col = colorset[color.tic])
                     #}
+                    conditional = { # up/down market linear fit for conditional beta
+                    # @todo: remove from default action
+                        bull.lm = lm( merged.assets.df[,1] ~ merged.assets.df[,2], subset = (merged.assets.df[,2] >0))
+                        bear.lm = lm( merged.assets.df[,1] ~ merged.assets.df[,2], subset = (merged.assets.df[,2] <0))
+                        segments(xmin, bear.lm$coef[1] + bear.lm$coef[2]*xmin, 0, bear.lm$coef[1], col = colorset[color.tic], lwd=lwd)
+                        segments(xmax, bull.lm$coef[1] + bull.lm$coef[2]*xmax, 0, bull.lm$coef[1], col = colorset[color.tic], lwd=lwd)
+                    },
+                    quadratic = { 
+                        model2.lm = lm( merged.assets.df[,1] ~ merged.assets.df[,2] + I(merged.assets.df[,2]^2))
+                        curve(predict(model2.lm, newdata = merged.assets.df[,2]), add = TRUE, col = "red")
+
+                    }
                )
            } # end fit
 
@@ -121,7 +149,7 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
     if(!is.null(legend.loc)){
         # There's no good place to put this automatically, except under the graph.
         # That requires a different solution, but here's the quick fix
-        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, pch = symbolset, cex=cex, border.col = elementcolor, lwd = 1, bg = "white", legend = legendnames)
+        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, pch = symbolset, cex=legend.cex, border.col = elementcolor, lwd = 1, bg = "white", legend = legendnames)
     }
 
     }
@@ -130,15 +158,23 @@ function (Ra, Rb, Rf, excess.returns = FALSE, reference.grid = TRUE, main = "Tit
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Regression.R,v 1.7 2007/12/29 15:38:06 peter Exp $
+# $Id: chart.Regression.R,v 1.9 2008-06-02 16:05:19 brian Exp $
 #
 ###############################################################################
 # $Log: chart.Regression.R,v $
+# Revision 1.9  2008-06-02 16:05:19  brian
+# - update copyright to 2004-2008
+#
+# Revision 1.8  2008-04-18 03:38:50  peter
+# - fixed x-axis
+# - added method for conditional beta lines
+# - added notes for extending fct to gauging market timing
+#
 # Revision 1.7  2007/12/29 15:38:06  peter
 # - fixed switch statement
 #
